Encoder

Struct Encoder 

pub struct Encoder<S, W: Write> { /* private fields */ }
WARC format writer

Implementations

Source

impl<S, W: Write> Encoder<S, W>

pub fn get_ref(&self) -> &W

pub fn get_mut(&mut self) -> &mut W

Source

impl<W: Write> Encoder<EncStateHeader, W>

pub fn new(dest: W, config: EncoderConfig) -> Self

Create a new encoder.

The destination writer should not be a compression stream. To enable compression, you must configure it with EncoderConfig.

pub fn write_header( self, header: &WarcHeader, ) -> Result<Encoder<EncStateBlock, W>, GeneralError>

Start a new WARC record with a given header.

The validation function will be called on the header before writing it to the stream.

Consumes the writer and returns a writer that has typestate transitioned to writing the WARC block portion of the record.

pub fn finish(self) -> Result<W>

Flushes any buffered data and returns the underlying stream.

You must call this function before dropping the struct in order to have a valid WARC file.

Source

impl<W: Write> Encoder<EncStateBlock, W>

pub fn finish_block(self) -> Result<Encoder<EncStateHeader, W>>

Indicate writing the block portion of a WARC record has completed.

Consumes the writer and returns a typestate transitioned writer for writing a new record.