pub struct Encoder<S, W: Write> { /* private fields */ }Expand description
WARC format writer
Implementations
Sourceimpl<W: Write> Encoder<EncStateHeader, W>
impl<W: Write> Encoder<EncStateHeader, W>
Sourcepub fn new(dest: W, config: EncoderConfig) -> Self
pub fn new(dest: W, config: EncoderConfig) -> Self
Create a new encoder.
The destination writer should not be a compression stream. To enable
compression, you must configure it with EncoderConfig.
Sourcepub fn write_header(
self,
header: &WarcHeader,
) -> Result<Encoder<EncStateBlock, W>, GeneralError>
pub fn write_header( self, header: &WarcHeader, ) -> Result<Encoder<EncStateBlock, W>, GeneralError>
Start a new WARC record with a given header.
The validation function will be called on the header before writing it to the stream.
Consumes the writer and returns a writer that has typestate transitioned to writing the WARC block portion of the record.
Sourceimpl<W: Write> Encoder<EncStateBlock, W>
impl<W: Write> Encoder<EncStateBlock, W>
Sourcepub fn finish_block(self) -> Result<Encoder<EncStateHeader, W>>
pub fn finish_block(self) -> Result<Encoder<EncStateHeader, W>>
Indicate writing the block portion of a WARC record has completed.
Consumes the writer and returns a typestate transitioned writer for writing a new record.